==> gaussrate9.1.tar.gz: gaussrate/source/head_gr.f <==
C***********************************************************************
C  HEADR
C***********************************************************************
C
      SUBROUTINE headr
C
C     PRINTS OUT PROGRAM HEADER TO UNIT FU6
C
C     CALLED BY:
C                MAIN
C
C
C   INCLUDE FILE ADDED 15/08/91
C   FORMAT STATEMENTS MODIFIED TO MAKE OUTPUT MORE CLEAR
C
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
      include 'param.inc'                                               1508GL91
C
C
      write (fu6,1000)
      write (fu6,100)
      write (fu6,200)
      write (fu6,1300)
      write (fu6,300)
      WRITE (FU6,1100)
      WRITE (FU6,1200)
      WRITE (FU6,1300)
      WRITE (FU6,1400)
      WRITE (FU6,1500)
      WRITE (FU6,1600)
      WRITE (FU6,1700)
      WRITE (FU6,1300)
      write (fu6,400)
      write (fu6,500)
      write (fu6,501)
      write (fu6,502)
      write (fu6,1000)
C
C
      RETURN
C
  100 FORMAT (/3X,'GAUSSRATE version 9.1/P9.1-G03/G98/G94 ',            0701TA03
     *           '(July 2003)',/)
  200 FORMAT (3X,'by Jose C. Corchado, Yao-Yuan Chuang, ',
     *           'Elena L. Coitino,',
     *       /3X,'and Donald G. Truhlar',/)
  300 FORMAT (3X,'Based on')
  400 FORMAT (3X,'and',/)
 1000 FORMAT (/,80(1H*))
 1100 FORMAT (/3X,'POLYRATE version 9.1',/)
 1200 FORMAT (3X,'Jose C. Corchado, Yao-Yuan Chuang, ',
     *           'Patton L. Fast, Jordi Villa,',
     *       /3X,'Wei-Ping Hu, Yi-Ping Liu, ',
     *           'Gillian C. Lynch, Kiet A. Nguyen,',
     *       /3X,'Charles F. Jackels, Vasilios S. Melissas, ',
     *           'Benjamin J. Lynch,',       
     *       /3X,'Ivan Rossi, Elena L. Coitino, ',
     *           'Antonio Fernandez Ramos,',
     *       /3X,'Jingzhi Pu, and Titus V. Albu')
 1300 FORMAT (6X,'Department of Chemistry and Supercomputer Institute',
     *       /6X,'University of Minnesota, Minneapolis, Minnesota',/)
 1400 FORMAT (3X,'Rozeanne Steckler',
     *     /6X,'San Diego Supercomputer Center, La Jolla, California',/)
 1500 FORMAT (3X,'Bruce C. Garrett',
     *       /6X,'Environmental Molecular Sciences Laboratory',
     *       /6X,'Pacific Northwest Laboratory, Richland, Washington',/)
 1600 FORMAT (3X,'Alan D. Isaacson',
     *       /6X,'Department of Chemistry, Miami University, ',
     *           'Oxford, Ohio',/)
 1700 FORMAT (3X,'and Donald G. Truhlar')
c
  500 FORMAT (3x,'GAUSSIAN 03',/,
     */,3X,'M. J. Frisch, G. W. Trucks,',
     *     ' H. B. Schlegel, G. E. Scuseria,',
     */,3X,'M. A. Robb, J. R. Cheeseman,',
     *     ' J. A. Montgomery, Jr., T. Vreven,',
     */,3X,'K. N. Kudin, J. C. Burant,',
     *     ' J. M. Millam, S. S. Iyengar, J. Tomasi,',
     */,3X,'V. Barone, B. Mennucci,',
     *     ' M. Cossi, G. Scalmani, N. Rega,',
     */,3X,'G. A. Petersson, H. Nakatsuji,',
     *     ' M. Hada, M. Ehara, K. Toyota,',
     */,3X,'R. Fukuda, J. Hasegawa, M. Ishida,',
     *     ' T. Nakajima, Y. Honda, O. Kitao,',
     */,3X,'H. Nakai, M. Klene, X. Li,',
     *     ' J. E. Knox, H. P. Hratchian, J. B. Cross,',
     */,3X,'C. Adamo, J. Jaramillo,',
     *     ' R. Gomperts, R. E. Stratmann, O. Yazyev,',
     */,3X,'A. J. Austin, R. Cammi,',
     *     ' C. Pomelli, J. W. Ochterski, P. Y. Ayala,',
     */,3X,'K. Morokuma, G. A. Voth,',
     *     ' P. Salvador, J. J. Dannenberg,',
     */,3X,'V. G. Zakrzewski, S. Dapprich,',
     *     ' A. D. Daniels, M. C. Strain,',
     */,3X,'O. Farkas, D. K. Malick,',
     *     ' A. D. Rabuck, K. Raghavachari,',
     */,3X,'J. B. Foresman, J. V. Ortiz,',
     *     ' Q. Cui, A. G. Baboul, S. Clifford,',
     */,3X,'J. Cioslowski, B. B. Stefanov,',
     *     ' G. Liu, A. Liashenko, P. Piskorz,',
     */,3X,'I. Komaromi, R. L. Martin,',
     *     ' D. J. Fox, T. Keith, M. A. Al-Laham,',
     */,3X,'C. Y. Peng, A. Nanayakkara,',
     *     ' M. Challacombe, P. M. W. Gill,',
     */,3X,'B. Johnson, W. Chen,',
     *     ' M. W. Wong, C. Gonzalez, and J. A. Pople,',
     */,3X,'Gaussian, Inc., Pittsburgh PA, 2003.')
c
  501 FORMAT (3x,/,3x,'or',/,/,3x,'GAUSSIAN 98',/,
     */,3X,'M. J. Frisch, G. W. Trucks,',
     *     ' H. B. Schlegel, G. E. Scuseria,',
     */,3X,'M. A. Robb, J. R. Cheeseman,',
     *     ' V. G. Zakrzewski, J. A. Montgomery, Jr.,',
     */,3X,'R. E. Stratmann, J. C. Burant,',
     *     ' S. Dapprich, J. M. Millam,',
     */,3X,'A. D. Daniels, K. N. Kudin,',
     *     ' M. C. Strain, O. Farkas, J. Tomasi,',
     */,3X,'V. Barone, M. Cossi, R. Cammi,',
     *     '  B. Mennucci, C. Pomelli, C. Adamo,',
     */,3X,'S. Clifford, J. Ochterski,',
     *     ' G. A. Petersson, P. Y. Ayala, Q. Cui,',
     */,3X,'K. Morokuma, P. Salvador,',
     *     ' J. J. Dannenberg, D. K. Malick,',
     */,3X,'A. D. Rabuck, K. Raghavachari,',
     *     ' J. B. Foresman, J. Cioslowski,',
     */,3X,'J. V. Ortiz, A. G. Baboul,',
     *     ' B. B. Stefanov, G. Liu, A. Liashenko,',
     */,3X,'P. Piskorz, I. Komaromi,',
     *     ' R. Gomperts, R. L. Martin, D. J. Fox,',
     */,3X,'T. Keith, M. A. Al-Laham,',
     *     ' C. Y. Peng, A. Nanayakkara, M. Challacombe,',
     */,3X,'P. M. W. Gill, B. Johnson,',
     *     ' W. Chen, M. W. Wong, J. L. Andres,',
     */,3X,'C. Gonzalez, M. Head-Gordon,',
     *     ' E. S. Replogle, and J. A. Pople,',
     */,3X,'Gaussian, Inc., Pittsburgh PA, 2001.')
c
  502 FORMAT (3x,/,3x,'or',/,/,3x,'GAUSSIAN 94',/,
     */,3X,'M. J. Frisch, G. W. Trucks,',
     *     ' H. B. Schlegel, P. M. W. Gill,',
     */,3X,'B. G. Johnson, M. A. Robb,',
     *     ' J. R. Cheeseman, T. Keith,',
     */,3X,'G. A. Petersson, J. A. Montgomery,',
     *     ' K. Raghavachari,',
     */,3X,'M. A. Al-Laham, V. G. Zakrzewski,',
     *     ' J. V. Ortiz, J. B. Foresman,',
     */,3X,'J. Cioslowski, B. B. Stefanov,',
     *     ' A. Nanayakkara, M. Challacombe,',
     */,3X,'C. Y. Peng, P. Y. Ayala,',
     *     ' W. Chen, M. W. Wong, J. L. Andres,',
     */,3X,'E. S. Replogle, R. Gomperts,',
     *     ' R. L. Martin, D. J. Fox,',
     */,3X,'J. S. Binkley, D. J. Defrees,',
     *     ' J. Baker, J. P. Stewart,',
     */,3X,'M. Head-Gordon, C. Gonzalez,',
     *     ' and J. A. Pople,',
     */,3X,'Gaussian, Inc., Pittsburgh PA, 1995.')
c
      END

==> gaussrate9.7.tar.gz: gaussrate/source/head_gr.f <==
C***********************************************************************
C  HEADR
C***********************************************************************
C
      SUBROUTINE headr
C
C     PRINTS OUT PROGRAM HEADER TO UNIT FU6
C
C     CALLED BY:
C                MAIN
C
C
C   INCLUDE FILE ADDED 15/08/91
C   FORMAT STATEMENTS MODIFIED TO MAKE OUTPUT MORE CLEAR
C
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
      include 'param.inc'                                               1508GL91
C
C
      write (fu6,1000)
      write (fu6,100)
      write (fu6,200)
      write (fu6,1300)
      write (fu6,300)
      WRITE (FU6,1100)
      WRITE (FU6,1200)
      WRITE (FU6,1300)
      WRITE (FU6,1400)
      WRITE (FU6,1500)
      WRITE (FU6,1600)
      WRITE (FU6,1700)
      WRITE (FU6,1300)
      write (fu6,400)
      write (fu6,500)
      write (fu6,501)
      write (fu6,502)
      write (fu6,1000)
C
C
      RETURN
C
  100 FORMAT (/3X,'GAUSSRATE version 9.7/P9.7-G03/G98/G94 ',            0110BE07
     *           '(June 2007)',/)                                       0629JZ07
  200 FORMAT (3X,'by Jose C. Corchado, Yao-Yuan Chuang, ',
     *           'Elena L. Coitino, Benjamin A. Ellingson, ',
     *       /3X,'Jingjing Zheng, and Donald G. Truhlar',/)
  300 FORMAT (3X,'Based on')
  400 FORMAT (3X,'and',/)
 1000 FORMAT (/,80(1H*))
 1100 FORMAT (/3X,'POLYRATE version 9.7',/)
 1200 FORMAT (3X,'Jose C. Corchado, Yao-Yuan Chuang, Patton L. Fast,',
     *       /3X,'Wei-Ping Hu, Yi-Ping Liu, Gillian C. Lynch,',
     *       /3X,'Kiet A. Nguyen, Charles F. Jackels,',
     *       /3X,'Antonio Fernandez Ramos, Benjamin A. Ellingson,',
     *       /3X,'Benjamin J. Lynch, Jingjing Zheng, Vasilios S.', 
     *       /3X,'Melissas, Jordi Villa, Ivan Rossi,Elena L. Coitino,',
     *       /3X,'Jingzhi Pu, and Titus V. Albu')
 1300 FORMAT (6X,'Department of Chemistry and Supercomputer Institute',
     *       /6X,'University of Minnesota, Minneapolis, Minnesota',/)
 1400 FORMAT (3X,'Rozeanne Steckler',
     *     /6X,'San Diego Supercomputer Center, La Jolla, California',/)
 1500 FORMAT (3X,'Bruce C. Garrett',
     *       /6X,'Environmental Molecular Sciences Laboratory',
     *       /6X,'Pacific Northwest Laboratory, Richland, Washington',/)
 1600 FORMAT (3X,'Alan D. Isaacson',
     *       /6X,'Department of Chemistry, Miami University, ',
     *           'Oxford, Ohio',/)
 1700 FORMAT (3X,'and Donald G. Truhlar')
c
  500 FORMAT (3x,'GAUSSIAN 03',/,
     */,3X,'M. J. Frisch, G. W. Trucks,',
     *     ' H. B. Schlegel, G. E. Scuseria,',
     */,3X,'M. A. Robb, J. R. Cheeseman,',
     *     ' J. A. Montgomery, Jr., T. Vreven,',
     */,3X,'K. N. Kudin, J. C. Burant,',
     *     ' J. M. Millam, S. S. Iyengar, J. Tomasi,',
     */,3X,'V. Barone, B. Mennucci,',
     *     ' M. Cossi, G. Scalmani, N. Rega,',
     */,3X,'G. A. Petersson, H. Nakatsuji,',
     *     ' M. Hada, M. Ehara, K. Toyota,',
     */,3X,'R. Fukuda, J. Hasegawa, M. Ishida,',
     *     ' T. Nakajima, Y. Honda, O. Kitao,',
     */,3X,'H. Nakai, M. Klene, X. Li,',
     *     ' J. E. Knox, H. P. Hratchian, J. B. Cross,',
     */,3X,'C. Adamo, J. Jaramillo,',
     *     ' R. Gomperts, R. E. Stratmann, O. Yazyev,',
     */,3X,'A. J. Austin, R. Cammi,',
     *     ' C. Pomelli, J. W. Ochterski, P. Y. Ayala,',
     */,3X,'K. Morokuma, G. A. Voth,',
     *     ' P. Salvador, J. J. Dannenberg,',
     */,3X,'V. G. Zakrzewski, S. Dapprich,',
     *     ' A. D. Daniels, M. C. Strain,',
     */,3X,'O. Farkas, D. K. Malick,',
     *     ' A. D. Rabuck, K. Raghavachari,',
     */,3X,'J. B. Foresman, J. V. Ortiz,',
     *     ' Q. Cui, A. G. Baboul, S. Clifford,',
     */,3X,'J. Cioslowski, B. B. Stefanov,',
     *     ' G. Liu, A. Liashenko, P. Piskorz,',
     */,3X,'I. Komaromi, R. L. Martin,',
     *     ' D. J. Fox, T. Keith, M. A. Al-Laham,',
     */,3X,'C. Y. Peng, A. Nanayakkara,',
     *     ' M. Challacombe, P. M. W. Gill,',
     */,3X,'B. Johnson, W. Chen,',
     *     ' M. W. Wong, C. Gonzalez, and J. A. Pople,',
     */,3X,'Gaussian, Inc., Pittsburgh PA, 2003.')
c
  501 FORMAT (3x,/,3x,'or',/,/,3x,'GAUSSIAN 98',/,
     */,3X,'M. J. Frisch, G. W. Trucks,',
     *     ' H. B. Schlegel, G. E. Scuseria,',
     */,3X,'M. A. Robb, J. R. Cheeseman,',
     *     ' V. G. Zakrzewski, J. A. Montgomery, Jr.,',
     */,3X,'R. E. Stratmann, J. C. Burant,',
     *     ' S. Dapprich, J. M. Millam,',
     */,3X,'A. D. Daniels, K. N. Kudin,',
     *     ' M. C. Strain, O. Farkas, J. Tomasi,',
     */,3X,'V. Barone, M. Cossi, R. Cammi,',
     *     '  B. Mennucci, C. Pomelli, C. Adamo,',
     */,3X,'S. Clifford, J. Ochterski,',
     *     ' G. A. Petersson, P. Y. Ayala, Q. Cui,',
     */,3X,'K. Morokuma, P. Salvador,',
     *     ' J. J. Dannenberg, D. K. Malick,',
     */,3X,'A. D. Rabuck, K. Raghavachari,',
     *     ' J. B. Foresman, J. Cioslowski,',
     */,3X,'J. V. Ortiz, A. G. Baboul,',
     *     ' B. B. Stefanov, G. Liu, A. Liashenko,',
     */,3X,'P. Piskorz, I. Komaromi,',
     *     ' R. Gomperts, R. L. Martin, D. J. Fox,',
     */,3X,'T. Keith, M. A. Al-Laham,',
     *     ' C. Y. Peng, A. Nanayakkara, M. Challacombe,',
     */,3X,'P. M. W. Gill, B. Johnson,',
     *     ' W. Chen, M. W. Wong, J. L. Andres,',
     */,3X,'C. Gonzalez, M. Head-Gordon,',
     *     ' E. S. Replogle, and J. A. Pople,',
     */,3X,'Gaussian, Inc., Pittsburgh PA, 2001.')
c
  502 FORMAT (3x,/,3x,'or',/,/,3x,'GAUSSIAN 94',/,
     */,3X,'M. J. Frisch, G. W. Trucks,',
     *     ' H. B. Schlegel, P. M. W. Gill,',
     */,3X,'B. G. Johnson, M. A. Robb,',
     *     ' J. R. Cheeseman, T. Keith,',
     */,3X,'G. A. Petersson, J. A. Montgomery,',
     *     ' K. Raghavachari,',
     */,3X,'M. A. Al-Laham, V. G. Zakrzewski,',
     *     ' J. V. Ortiz, J. B. Foresman,',
     */,3X,'J. Cioslowski, B. B. Stefanov,',
     *     ' A. Nanayakkara, M. Challacombe,',
     */,3X,'C. Y. Peng, P. Y. Ayala,',
     *     ' W. Chen, M. W. Wong, J. L. Andres,',
     */,3X,'E. S. Replogle, R. Gomperts,',
     *     ' R. L. Martin, D. J. Fox,',
     */,3X,'J. S. Binkley, D. J. Defrees,',
     *     ' J. Baker, J. P. Stewart,',
     */,3X,'M. Head-Gordon, C. Gonzalez,',
     *     ' and J. A. Pople,',
     */,3X,'Gaussian, Inc., Pittsburgh PA, 1995.')
c
      END
